@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   SPDX-License-Identifier: GPL-2.0-only
@@ -9,10 +9,6 @@
 #include "collectionexpirywidget.h"
 
 #include "attributes/expirecollectionattribute.h"
-#include "folder/foldersettings.h"
-#include "kernel/mailkernel.h"
-#include "mailcommon_debug.h"
-#include "util/mailutil.h"
 
 #include <KLocalizedString>
 #include <QVBoxLayout>
@@ -27,9 +23,7 @@ CollectionExpiryPage::CollectionExpiryPage(QWidget *parent)
     setPageTitle(i18nc("@title:tab Expiry settings for a folder.", "Expiry"));
 }
 
-CollectionExpiryPage::~CollectionExpiryPage()
-{
-}
+CollectionExpiryPage::~CollectionExpiryPage() = default;
 
 bool CollectionExpiryPage::canHandle(const Akonadi::Collection &col) const
 {
