@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ FilterActionMissingTemplateDialogTest::FilterActionMissingTemplateDialogTest(QOb
     QStandardPaths::setTestModeEnabled(true);
 }
 
-FilterActionMissingTemplateDialogTest::~FilterActionMissingTemplateDialogTest()
-{
-}
+FilterActionMissingTemplateDialogTest::~FilterActionMissingTemplateDialogTest() = default;
 
 void FilterActionMissingTemplateDialogTest::shouldHaveDefaultValue()
 {
