@@ -1,33 +1,20 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionplaysoundtest.h"
 #include "../filteractions/filteractionplaysound.h"
-#include <qtest.h>
 #include "filter/soundtestwidget.h"
+#include <QTest>
 
 FilterActionPlaySoundTest::FilterActionPlaySoundTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FilterActionPlaySoundTest::~FilterActionPlaySoundTest()
-{
-}
+FilterActionPlaySoundTest::~FilterActionPlaySoundTest() = default;
 
 void FilterActionPlaySoundTest::shouldBeValid()
 {
@@ -43,7 +30,7 @@ void FilterActionPlaySoundTest::shouldHaveDefaultValue()
     QWidget *w = filter.createParamWidget(nullptr);
     QVERIFY(w);
     QCOMPARE(w->objectName(), QStringLiteral("soundwidget"));
-    MailCommon::SoundTestWidget *soundTest = dynamic_cast<MailCommon::SoundTestWidget *>(w);
+    auto *soundTest = dynamic_cast<MailCommon::SoundTestWidget *>(w);
     QVERIFY(soundTest);
     QVERIFY(soundTest->url().isEmpty());
 }
