@@ -1,33 +1,20 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionremoveheadertest.h"
 #include "../filteractions/filteractionremoveheader.h"
-#include <QTest>
 #include <QComboBox>
+#include <QTest>
 
 FilterActionRemoveHeaderTest::FilterActionRemoveHeaderTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FilterActionRemoveHeaderTest::~FilterActionRemoveHeaderTest()
-{
-}
+FilterActionRemoveHeaderTest::~FilterActionRemoveHeaderTest() = default;
 
 void FilterActionRemoveHeaderTest::shouldHaveDefaultValue()
 {
@@ -68,21 +55,25 @@ void FilterActionRemoveHeaderTest::shouldNotExecuteActionWhenParameterIsEmpty()
 
 void FilterActionRemoveHeaderTest::shouldRemoveHeader()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "testheader: foo\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "\n"
-                            "test";
-    const QByteArray output = "From: foo@kde.org\n"
-                              "To: foo@kde.org\n"
-                              "Subject: test\n"
-                              "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                              "MIME-Version: 1.0\n"
-                              "\n"
-                              "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "testheader: foo\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
+    const QByteArray output =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRemoveHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
@@ -100,14 +91,16 @@ void FilterActionRemoveHeaderTest::shouldRemoveHeader()
 
 void FilterActionRemoveHeaderTest::shouldNotTryToRemoveHeaderWhenItDoesntExist()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "testheader2: foo\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "\n"
-                            "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "testheader2: foo\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRemoveHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
@@ -125,23 +118,27 @@ void FilterActionRemoveHeaderTest::shouldNotTryToRemoveHeaderWhenItDoesntExist()
 
 void FilterActionRemoveHeaderTest::shouldRemoveMultiHeader()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "testheader: foo\n"
-                            "testheader: foo\n"
-                            "testheader: bla\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "\n"
-                            "test";
-    const QByteArray output = "From: foo@kde.org\n"
-                              "To: foo@kde.org\n"
-                              "Subject: test\n"
-                              "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                              "MIME-Version: 1.0\n"
-                              "\n"
-                              "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "testheader: foo\n"
+        "testheader: foo\n"
+        "testheader: bla\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
+    const QByteArray output =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRemoveHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
