@@ -1,3 +1,8 @@
+/*
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+
+  SPDX-License-Identifier: GPL-2.0-only
+*/
 #include "filteractionsettransporttest.h"
 #include "../filteractions/filteractionsettransport.h"
 #include <MailTransport/TransportComboBox>
@@ -8,9 +13,7 @@ FilterActionSetTransportTest::FilterActionSetTransportTest(QObject *parent)
 {
 }
 
-FilterActionSetTransportTest::~FilterActionSetTransportTest()
-{
-}
+FilterActionSetTransportTest::~FilterActionSetTransportTest() = default;
 
 void FilterActionSetTransportTest::shouldBeEmpty()
 {
