@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -16,9 +16,7 @@ FilterImporterPathCacheTest::FilterImporterPathCacheTest(QObject *parent)
 {
 }
 
-FilterImporterPathCacheTest::~FilterImporterPathCacheTest()
-{
-}
+FilterImporterPathCacheTest::~FilterImporterPathCacheTest() = default;
 
 void FilterImporterPathCacheTest::shouldReturnEmptyStringWhenListIsEmpty()
 {
