@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -17,9 +17,7 @@ InvalidFilterDialogTest::InvalidFilterDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-InvalidFilterDialogTest::~InvalidFilterDialogTest()
-{
-}
+InvalidFilterDialogTest::~InvalidFilterDialogTest() = default;
 
 void InvalidFilterDialogTest::shouldHaveDefaultValue()
 {
