@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,9 +14,7 @@ InvalidFilterWidgetTest::InvalidFilterWidgetTest(QObject *parent)
 {
 }
 
-InvalidFilterWidgetTest::~InvalidFilterWidgetTest()
-{
-}
+InvalidFilterWidgetTest::~InvalidFilterWidgetTest() = default;
 
 void InvalidFilterWidgetTest::shouldHaveDefaultValue()
 {
