@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,6 +22,6 @@ public:
 private:
     void readConfig();
     void writeConfig();
-    MailCommon::KMFilterAccountList *mAccountList = nullptr;
+    MailCommon::KMFilterAccountList *const mAccountList;
 };
 }
