@@ -1,21 +1,17 @@
 /*
 
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filteractionmissingfolderdialog.h"
-#include "filter/kmfilteraccountlist.h"
 #include "folder/folderrequester.h"
 #include "kernel/mailkernel.h"
-#include "tag/addtagdialog.h"
 #include "util/mailutil.h"
 
 #include <Akonadi/EntityMimeTypeFilterModel>
 
-#include <KIdentityManagement/IdentityCombo>
-
 #include <KLocalizedString>
 
 #include <KConfigGroup>
@@ -24,12 +20,17 @@
 #include <QListWidget>
 #include <QPushButton>
 #include <QVBoxLayout>
+namespace
+{
+static const char myFilterActionMissingCollectionDialogConfigGroupName[] = "FilterActionMissingCollectionDialog";
+}
 
 FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(const Akonadi::Collection::List &list,
                                                                  const QString &filtername,
                                                                  const QString &argStr,
                                                                  QWidget *parent)
     : QDialog(parent)
+    , mFolderRequester(new MailCommon::FolderRequester(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Folder"));
@@ -61,18 +62,18 @@ FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(const Akonadi::
     label->setObjectName(QStringLiteral("folderlabel"));
     label->setWordWrap(true);
     if (filtername.isEmpty()) {
-        label->setText(i18n("Please select a folder"));
+        label->setText(i18n("Please select a folder:"));
     } else {
         label->setText(
             i18n("Filter folder is missing. "
-                 "Please select a folder to use with filter \"%1\"",
+                 "Please select a folder to use with filter \"%1\":",
                  filtername));
     }
     mainLayout->addWidget(label);
-    mFolderRequester = new MailCommon::FolderRequester(this);
     mFolderRequester->setObjectName(QStringLiteral("folderrequester"));
     connect(mFolderRequester, &MailCommon::FolderRequester::folderChanged, this, &FilterActionMissingFolderDialog::slotFolderChanged);
     mainLayout->addWidget(mFolderRequester);
+    mainLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Expanding));
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
@@ -93,7 +94,7 @@ FilterActionMissingFolderDialog::~FilterActionMissingFolderDialog()
 
 void FilterActionMissingFolderDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingCollectionDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingCollectionDialogConfigGroupName);
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -103,7 +104,7 @@ void FilterActionMissingFolderDialog::readConfig()
 
 void FilterActionMissingFolderDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingCollectionDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingCollectionDialogConfigGroupName);
     group.writeEntry("Size", size());
 }
 
