@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,14 @@
 #include <QVBoxLayout>
 
 using namespace MailCommon;
+namespace
+{
+static const char myFilterActionMissingSoundUrlDialogGroupName[] = "FilterActionMissingSoundUrlDialog";
+}
 
 FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent)
     : QDialog(parent)
+    , mUrlWidget(new KUrlRequester(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select sound"));
@@ -37,7 +42,6 @@ FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QStri
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mUrlWidget = new KUrlRequester(this);
     mUrlWidget->setObjectName(QStringLiteral("urlwidget"));
     mainLayout->addWidget(mUrlWidget);
 
@@ -65,7 +69,7 @@ QString FilterActionMissingSoundUrlDialog::soundUrl() const
 
 void FilterActionMissingSoundUrlDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingSoundUrlDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingSoundUrlDialogGroupName);
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -75,6 +79,6 @@ void FilterActionMissingSoundUrlDialog::readConfig()
 
 void FilterActionMissingSoundUrlDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingSoundUrlDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingSoundUrlDialogGroupName);
     group.writeEntry("Size", size());
 }
