@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,12 +19,17 @@
 #include <QVBoxLayout>
 
 using namespace MailCommon;
+namespace
+{
+static const char myFilterActionMissingTagDialogGroupName[] = "FilterActionMissingTagDialog";
+}
 
 FilterActionMissingTagDialog::FilterActionMissingTagDialog(const QMap<QUrl, QString> &tagList,
                                                            const QString &filtername,
                                                            const QString &argsStr,
                                                            QWidget *parent)
     : QDialog(parent)
+    , mTagList(new QListWidget(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Tag"));
@@ -42,7 +47,6 @@ FilterActionMissingTagDialog::FilterActionMissingTagDialog(const QMap<QUrl, QStr
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mTagList = new QListWidget(this);
     mTagList->setObjectName(QStringLiteral("taglist"));
 
     QMap<QUrl, QString>::const_iterator map = tagList.constBegin();
@@ -59,7 +63,7 @@ FilterActionMissingTagDialog::FilterActionMissingTagDialog(const QMap<QUrl, QStr
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    okButton->setShortcut(QKeySequence{Qt::CTRL | Qt::Key_Return});
     auto user1Button = new QPushButton(this);
     user1Button->setObjectName(QStringLiteral("addtag"));
     user1Button->setText(i18n("Add Tag..."));
@@ -80,7 +84,7 @@ FilterActionMissingTagDialog::~FilterActionMissingTagDialog()
 
 void FilterActionMissingTagDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingTagDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingTagDialogGroupName);
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -90,7 +94,7 @@ void FilterActionMissingTagDialog::readConfig()
 
 void FilterActionMissingTagDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingTagDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterActionMissingTagDialogGroupName);
     group.writeEntry("Size", size());
 }
 
@@ -99,7 +103,7 @@ QString FilterActionMissingTagDialog::selectedTag() const
     if (mTagList->currentItem()) {
         return mTagList->currentItem()->data(UrlData).toString();
     }
-    return QString();
+    return {};
 }
 
 void FilterActionMissingTagDialog::slotAddTag()
