@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,6 +27,6 @@ private:
     void writeConfig();
 
     enum TypeData { UrlData = Qt::UserRole + 1 };
-    QListWidget *mTagList = nullptr;
+    QListWidget *const mTagList;
 };
 }
