@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,6 @@ public:
 private:
     void writeConfig();
     void readConfig();
-    MailTransport::TransportComboBox *mComboBoxTransport = nullptr;
+    MailTransport::TransportComboBox *const mComboBoxTransport;
 };
 }
-
