@@ -1,28 +1,16 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONWITHTEST_H
-#define MAILCOMMON_FILTERACTIONWITHTEST_H
+#pragma once
 
 #include "filteraction.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class FilterActionWithTest : public FilterAction
 {
     Q_OBJECT
@@ -30,7 +18,7 @@ public:
     /**
      * @copydoc FilterAction::FilterAction
      */
-    FilterActionWithTest(const QString &name, const QString &label, QObject *parent = nullptr);
+    explicit FilterActionWithTest(const QString &name, const QString &label, QObject *parent = nullptr);
 
     /**
      * @copydoc FilterAction::~FilterAction
@@ -81,5 +69,3 @@ protected:
     QString mParameter;
 };
 }
-
-#endif
