@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ FilterConvertToSieve::FilterConvertToSieve(const QVector<MailFilter *> &filters)
 {
 }
 
-FilterConvertToSieve::~FilterConvertToSieve()
-{
-}
+FilterConvertToSieve::~FilterConvertToSieve() = default;
 
 void FilterConvertToSieve::convert()
 {
@@ -38,8 +36,7 @@ void FilterConvertToSieve::convert()
         }
         result = requireStr + code;
     }
-    QPointer<FilterConvertToSieveResultDialog> dlg = new FilterConvertToSieveResultDialog;
-    dlg->setCode(result);
-    dlg->exec();
-    delete dlg;
+    FilterConvertToSieveResultDialog dlg;
+    dlg.setCode(result);
+    dlg.exec();
 }
