@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ FilterconverttosievePurposeMenuWidget::FilterconverttosievePurposeMenuWidget(QWi
 {
 }
 
-FilterconverttosievePurposeMenuWidget::~FilterconverttosievePurposeMenuWidget()
-{
-}
+FilterconverttosievePurposeMenuWidget::~FilterconverttosievePurposeMenuWidget() = default;
 
 QByteArray FilterconverttosievePurposeMenuWidget::text()
 {
