@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,13 @@
 #include <QVBoxLayout>
 
 using namespace MailCommon;
-
+namespace
+{
+static const char myFilterConvertToSieveResultDialogName[] = "FilterConvertToSieveResultDialog";
+}
 FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *parent)
     : QDialog(parent)
+    , mEditor(new KPIMTextEdit::PlainTextEditorWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Convert to Sieve Script"));
     auto topLayout = new QVBoxLayout(this);
@@ -39,7 +43,6 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
     setModal(true);
     connect(saveButton, &QPushButton::clicked, this, &FilterConvertToSieveResultDialog::slotSave);
 
-    mEditor = new KPIMTextEdit::PlainTextEditorWidget;
     mEditor->editor()->setSpellCheckingSupport(false);
     mEditor->setObjectName(QStringLiteral("editor"));
     auto syntaxHighlighter = new KSyntaxHighlighting::SyntaxHighlighter(mEditor->editor()->document());
@@ -75,11 +78,9 @@ void FilterConvertToSieveResultDialog::setCode(const QString &code)
     mEditor->editor()->setPlainText(code);
 }
 
-static const char myConfigGroupName[] = "FilterConvertToSieveResultDialog";
-
 void FilterConvertToSieveResultDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterConvertToSieveResultDialogName);
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -89,7 +90,7 @@ void FilterConvertToSieveResultDialog::readConfig()
 
 void FilterConvertToSieveResultDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), myFilterConvertToSieveResultDialogName);
     group.writeEntry("Size", size());
     group.sync();
 }
