@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,14 +24,11 @@ public:
 
     void setCode(const QString &code);
 
-private Q_SLOTS:
-    void slotSave();
-
 private:
+    void slotSave();
     void readConfig();
     void writeConfig();
-    KPIMTextEdit::PlainTextEditorWidget *mEditor = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *const mEditor;
     KSyntaxHighlighting::Repository mSyntaxRepo;
 };
 }
-
