@@ -1,29 +1,17 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "mailcommon_debug.h"
 #include "filterimporterabstract.h"
 #include "filter/filteractions/filteractiondict.h"
 #include "filter/filtermanager.h"
 #include "filter/mailfilter.h"
+#include "mailcommon_debug.h"
 
-#include <QFile>
 #include <QDomDocument>
+#include <QFile>
 
 using namespace MailCommon;
 
@@ -32,9 +20,7 @@ FilterImporterAbstract::FilterImporterAbstract(bool interactive)
 {
 }
 
-FilterImporterAbstract::~FilterImporterAbstract()
-{
-}
+FilterImporterAbstract::~FilterImporterAbstract() = default;
 
 QVector<MailFilter *> FilterImporterAbstract::importFilter() const
 {
@@ -52,7 +38,7 @@ void FilterImporterAbstract::appendFilter(MailCommon::MailFilter *filter)
         return;
     }
 
-    //TODO verify number of condition
+    // TODO verify number of condition
     filter->purify();
     if (!filter->isEmpty()) {
         // the filter is valid:
@@ -96,8 +82,7 @@ bool FilterImporterAbstract::loadDomElement(QDomDocument &doc, QFile *file)
     int errorRow;
     int errorCol;
     if (!doc.setContent(file, &errorMsg, &errorRow, &errorCol)) {
-        qCDebug(MAILCOMMON_LOG) << "Unable to load document.Parse error in line " << errorRow
-                                << ", col " << errorCol << ": " << errorMsg;
+        qCDebug(MAILCOMMON_LOG) << "Unable to load document.Parse error in line " << errorRow << ", col " << errorCol << ": " << errorMsg;
         return false;
     }
     return true;
