@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimporterbalsa.h"
-#include "filter/filtermanager.h"
 #include "filter/mailfilter.h"
 #include "mailcommon_debug.h"
 
@@ -30,9 +29,7 @@ FilterImporterBalsa::FilterImporterBalsa()
 {
 }
 
-FilterImporterBalsa::~FilterImporterBalsa()
-{
-}
+FilterImporterBalsa::~FilterImporterBalsa() = default;
 
 QString FilterImporterBalsa::defaultFiltersSettingsPath()
 {
