@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimporterevolution.h"
-#include "filter/filtermanager.h"
 #include "filter/mailfilter.h"
 
 #include "mailcommon_debug.h"
@@ -38,9 +37,7 @@ FilterImporterEvolution::FilterImporterEvolution(QFile *file)
     }
 }
 
-FilterImporterEvolution::~FilterImporterEvolution()
-{
-}
+FilterImporterEvolution::~FilterImporterEvolution() = default;
 
 QString FilterImporterEvolution::defaultFiltersSettingsPath()
 {
