@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FILTERIMPORTER_FILTERIMPORTERSYLPHEED_P_H
-#define MAILCOMMON_FILTERIMPORTER_FILTERIMPORTERSYLPHEED_P_H
+#pragma once
 
 #include "filter/filterimporter/filterimporterabstract.h"
 
@@ -30,5 +29,3 @@ private:
     void parseActions(const QDomElement &e, MailCommon::MailFilter *filter);
 };
 }
-
-#endif /* FILTERIMPORTERSYLPHEED_P_H */
