@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,7 +26,7 @@ public:
 private:
     void writeConfig();
     void readConfig();
-    InvalidFilterWidget *mInvalidFilterWidget = nullptr;
-    InvalidFilterInfoWidget *mInvalidFilterInfoWidget = nullptr;
+    InvalidFilterWidget *const mInvalidFilterWidget;
+    InvalidFilterInfoWidget *const mInvalidFilterInfoWidget;
 };
 }
