@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,7 @@
 #include "invalidfilterinfo.h"
 using namespace MailCommon;
 
-InvalidFilterInfo::InvalidFilterInfo()
-{
-}
+InvalidFilterInfo::InvalidFilterInfo() = default;
 
 InvalidFilterInfo::InvalidFilterInfo(const QString &name, const QString &information)
     : mName(name)
