@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,9 +31,7 @@ InvalidFilterWidget::InvalidFilterWidget(QWidget *parent)
     vbox->addWidget(mInvalidFilterListWidget);
 }
 
-InvalidFilterWidget::~InvalidFilterWidget()
-{
-}
+InvalidFilterWidget::~InvalidFilterWidget() = default;
 
 void InvalidFilterWidget::setInvalidFilters(const QVector<InvalidFilterInfo> &lst)
 {
