@@ -2,7 +2,7 @@
   Filter Dialog
 
   SPDX-FileCopyrightText: Marc Mutz <mutz@kde.org>
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   based upon work by Stefan Taferner <taferner@kde.org>
 
@@ -13,7 +13,6 @@
 #include "kmfilterlistbox.h"
 #include "mailcommon_debug.h"
 
-#include "filteractions/filteractiondict.h"
 #include "filteractions/filteractionwidget.h"
 #include "filterimporterpathcache.h"
 #include "filterselectiondialog.h"
@@ -24,7 +23,6 @@ using MailCommon::FilterImporterExporter;
 #include "folder/folderrequester.h"
 #include "kernel/mailkernel.h"
 #include "search/searchpatternedit.h"
-#include "util/mailutil.h"
 #include <PimCommon/PimUtil>
 
 #include <Akonadi/ItemFetchJob>
