@@ -1,108 +1,28 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kmfilterlistbox.h"
-#include "mailfilter.h"
-#include "filtermanager.h"
 #include "filteractions/filteractiondict.h"
-#include <QInputDialog>
-#include "invalidfilters/invalidfilterinfo.h"
+#include "filtermanager.h"
 #include "invalidfilters/invalidfilterdialog.h"
-#include <KLocalizedString>
-#include <KListWidgetSearchLine>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QListWidget>
-#include <QShortcut>
-#include <KMessageBox>
+#include "invalidfilters/invalidfilterinfo.h"
 #include "mailcommon_debug.h"
+#include "mailfilter.h"
+#include <KListWidgetSearchLine>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <QHBoxLayout>
+#include <QInputDialog>
 #include <QKeyEvent>
+#include <QListWidget>
 #include <QPointer>
-
-// What's this help texts
-const char _wt_filterlist[]
-    = I18N_NOOP("<qt><p>This is the list of defined filters. "
-                "They are processed top-to-bottom.</p>"
-                "<p>Click on any filter to edit it "
-                "using the controls in the right-hand half "
-                "of the dialog.</p></qt>");
-
-const char _wt_filterlist_new[]
-    = I18N_NOOP("<qt><p>Click this button to create a new filter.</p>"
-                "<p>The filter will be inserted just before the currently-"
-                "selected one, but you can always change that "
-                "later on.</p>"
-                "<p>If you have clicked this button accidentally, you can undo this "
-                "by clicking on the <em>Delete</em> button.</p></qt>");
-
-const char _wt_filterlist_copy[]
-    = I18N_NOOP("<qt><p>Click this button to copy a filter.</p>"
-                "<p>If you have clicked this button accidentally, you can undo this "
-                "by clicking on the <em>Delete</em> button.</p></qt>");
-
-const char _wt_filterlist_delete[]
-    = I18N_NOOP("<qt><p>Click this button to <em>delete</em> the currently-"
-                "selected filter from the list above.</p>"
-                "<p>There is no way to get the filter back once "
-                "it is deleted, but you can always leave the "
-                "dialog by clicking <em>Cancel</em> to discard the "
-                "changes made.</p></qt>");
-
-const char _wt_filterlist_up[]
-    = I18N_NOOP("<qt><p>Click this button to move the currently-"
-                "selected filter <em>up</em> one in the list above.</p>"
-                "<p>This is useful since the order of the filters in the list "
-                "determines the order in which they are tried on messages: "
-                "The topmost filter gets tried first.</p>"
-                "<p>If you have clicked this button accidentally, you can undo this "
-                "by clicking on the <em>Down</em> button.</p></qt>");
-
-const char _wt_filterlist_down[]
-    = I18N_NOOP("<qt><p>Click this button to move the currently-"
-                "selected filter <em>down</em> one in the list above.</p>"
-                "<p>This is useful since the order of the filters in the list "
-                "determines the order in which they are tried on messages: "
-                "The topmost filter gets tried first.</p>"
-                "<p>If you have clicked this button accidentally, you can undo this "
-                "by clicking on the <em>Up</em> button.</p></qt>");
-
-const char _wt_filterlist_top[]
-    = I18N_NOOP("<qt><p>Click this button to move the currently-"
-                "selected filter to top of list.</p>"
-                "<p>This is useful since the order of the filters in the list "
-                "determines the order in which they are tried on messages: "
-                "The topmost filter gets tried first.</p></qt>");
-
-const char _wt_filterlist_bottom[]
-    = I18N_NOOP("<qt><p>Click this button to move the currently-"
-                "selected filter to bottom of list.</p>"
-                "<p>This is useful since the order of the filters in the list "
-                "determines the order in which they are tried on messages: "
-                "The topmost filter gets tried first.</p></qt>");
-
-const char _wt_filterlist_rename[]
-    = I18N_NOOP("<qt><p>Click this button to rename the currently-selected filter.</p>"
-                "<p>Filters are named automatically, as long as they start with "
-                "\"&lt;\".</p>"
-                "<p>If you have renamed a filter accidentally and want automatic "
-                "naming back, click this button and select <em>Clear</em> followed "
-                "by <em>OK</em> in the appearing dialog.</p></qt>");
+#include <QPushButton>
+#include <QShortcut>
+#include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
 //=============================================================================
 //
@@ -113,29 +33,31 @@ using namespace MailCommon;
 KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
     //----------- the list box
     mListWidget = new QListWidget(this);
     mListWidget->setMinimumWidth(150);
-    mListWidget->setWhatsThis(i18n(_wt_filterlist));
+    mListWidget->setWhatsThis(
+        i18n("<qt><p>This is the list of defined filters. "
+             "They are processed top-to-bottom.</p>"
+             "<p>Click on any filter to edit it "
+             "using the controls in the right-hand half "
+             "of the dialog.</p></qt>"));
     mListWidget->setDragDropMode(QAbstractItemView::InternalMove);
     mListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    connect(mListWidget->model(), &QAbstractItemModel::rowsMoved,
-            this, &KMFilterListBox::slotRowsMoved);
+    connect(mListWidget->model(), &QAbstractItemModel::rowsMoved, this, &KMFilterListBox::slotRowsMoved);
 
     mSearchListWidget = new KListWidgetSearchLine(this, mListWidget);
-    mSearchListWidget->setPlaceholderText(
-        i18nc("@info Displayed grayed-out inside the textbox, verb to search",
-              "Search"));
+    mSearchListWidget->setPlaceholderText(i18nc("@info Displayed grayed-out inside the textbox, verb to search", "Search"));
     mSearchListWidget->installEventFilter(this);
     layout->addWidget(mSearchListWidget);
     layout->addWidget(mListWidget);
 
     //----------- the first row of buttons
-    QWidget *hb = new QWidget(this);
-    QHBoxLayout *hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    auto hb = new QWidget(this);
+    auto hbHBoxLayout = new QHBoxLayout(hb);
+    hbHBoxLayout->setContentsMargins({});
     hbHBoxLayout->setSpacing(4);
 
     mBtnTop = new QPushButton(QString(), hb);
@@ -163,17 +85,41 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     mBtnDown->setToolTip(i18nc("Move selected filter down.", "Down"));
     mBtnTop->setToolTip(i18nc("Move selected filter to the top.", "Top"));
     mBtnBottom->setToolTip(i18nc("Move selected filter to the bottom.", "Bottom"));
-    mBtnUp->setWhatsThis(i18n(_wt_filterlist_up));
-    mBtnDown->setWhatsThis(i18n(_wt_filterlist_down));
-    mBtnBottom->setWhatsThis(i18n(_wt_filterlist_bottom));
-    mBtnTop->setWhatsThis(i18n(_wt_filterlist_top));
+    mBtnUp->setWhatsThis(
+        i18n("<qt><p>Click this button to move the currently-"
+             "selected filter <em>up</em> one in the list above.</p>"
+             "<p>This is useful since the order of the filters in the list "
+             "determines the order in which they are tried on messages: "
+             "The topmost filter gets tried first.</p>"
+             "<p>If you have clicked this button accidentally, you can undo this "
+             "by clicking on the <em>Down</em> button.</p></qt>"));
+    mBtnDown->setWhatsThis(
+        i18n("<qt><p>Click this button to move the currently-"
+             "selected filter <em>down</em> one in the list above.</p>"
+             "<p>This is useful since the order of the filters in the list "
+             "determines the order in which they are tried on messages: "
+             "The topmost filter gets tried first.</p>"
+             "<p>If you have clicked this button accidentally, you can undo this "
+             "by clicking on the <em>Up</em> button.</p></qt>"));
+    mBtnBottom->setWhatsThis(
+        i18n("<qt><p>Click this button to move the currently-"
+             "selected filter to bottom of list.</p>"
+             "<p>This is useful since the order of the filters in the list "
+             "determines the order in which they are tried on messages: "
+             "The topmost filter gets tried first.</p></qt>"));
+    mBtnTop->setWhatsThis(
+        i18n("<qt><p>Click this button to move the currently-"
+             "selected filter to top of list.</p>"
+             "<p>This is useful since the order of the filters in the list "
+             "determines the order in which they are tried on messages: "
+             "The topmost filter gets tried first.</p></qt>"));
 
     layout->addWidget(hb);
 
     //----------- the second row of buttons
     hb = new QWidget(this);
     hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    hbHBoxLayout->setContentsMargins({});
     hbHBoxLayout->setSpacing(4);
     mBtnNew = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnNew);
@@ -196,14 +142,35 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     mBtnCopy->setToolTip(i18n("Copy"));
     mBtnDelete->setToolTip(i18n("Delete"));
     mBtnRename->setToolTip(i18n("Rename"));
-    mBtnNew->setWhatsThis(i18n(_wt_filterlist_new));
-    mBtnCopy->setWhatsThis(i18n(_wt_filterlist_copy));
-    mBtnDelete->setWhatsThis(i18n(_wt_filterlist_delete));
-    mBtnRename->setWhatsThis(i18n(_wt_filterlist_rename));
+    mBtnNew->setWhatsThis(
+        i18n("<qt><p>Click this button to create a new filter.</p>"
+             "<p>The filter will be inserted just before the currently-"
+             "selected one, but you can always change that "
+             "later on.</p>"
+             "<p>If you have clicked this button accidentally, you can undo this "
+             "by clicking on the <em>Delete</em> button.</p></qt>"));
+    mBtnCopy->setWhatsThis(
+        i18n("<qt><p>Click this button to copy a filter.</p>"
+             "<p>If you have clicked this button accidentally, you can undo this "
+             "by clicking on the <em>Delete</em> button.</p></qt>"));
+    mBtnDelete->setWhatsThis(
+        i18n("<qt><p>Click this button to <em>delete</em> the currently-"
+             "selected filter from the list above.</p>"
+             "<p>There is no way to get the filter back once "
+             "it is deleted, but you can always leave the "
+             "dialog by clicking <em>Cancel</em> to discard the "
+             "changes made.</p></qt>"));
+    mBtnRename->setWhatsThis(
+        i18n("<qt><p>Click this button to rename the currently-selected filter.</p>"
+             "<p>Filters are named automatically, as long as they start with "
+             "\"&lt;\".</p>"
+             "<p>If you have renamed a filter accidentally and want automatic "
+             "naming back, click this button and select <em>Clear</em> followed "
+             "by <em>OK</em> in the appearing dialog.</p></qt>"));
 
     layout->addWidget(hb);
 
-    QShortcut *shortcut = new QShortcut(this);
+    auto shortcut = new QShortcut(this);
     shortcut->setKey(Qt::Key_Delete);
     connect(shortcut, &QShortcut::activated, this, &KMFilterListBox::slotDelete);
 
@@ -229,14 +196,12 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     enableControls();
 }
 
-KMFilterListBox::~KMFilterListBox()
-{
-}
+KMFilterListBox::~KMFilterListBox() = default;
 
 bool KMFilterListBox::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress && obj == mSearchListWidget) {
-        QKeyEvent *key = static_cast<QKeyEvent *>(event);
+        auto key = static_cast<QKeyEvent *>(event);
         if ((key->key() == Qt::Key_Enter) || (key->key() == Qt::Key_Return)) {
             event->accept();
             return true;
@@ -263,7 +228,7 @@ void KMFilterListBox::slotFilterEnabledChanged(QListWidgetItem *item)
         qCDebug(MAILCOMMON_LOG) << "Called while no filter is selected, ignoring.";
         return;
     }
-    QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
+    auto itemFilter = static_cast<QListWidgetFilterItem *>(item);
     MailCommon::MailFilter *filter = itemFilter->filter();
     filter->setEnabled((item->checkState() == Qt::Checked));
     Q_EMIT filterUpdated(filter);
@@ -271,9 +236,9 @@ void KMFilterListBox::slotFilterEnabledChanged(QListWidgetItem *item)
 
 void KMFilterListBox::slotRowsMoved(const QModelIndex &, int sourcestart, int sourceEnd, const QModelIndex &, int destinationRow)
 {
-    Q_UNUSED(sourceEnd);
-    Q_UNUSED(sourcestart);
-    Q_UNUSED(destinationRow);
+    Q_UNUSED(sourceEnd)
+    Q_UNUSED(sourcestart)
+    Q_UNUSED(destinationRow)
     enableControls();
 
     Q_EMIT filterOrderAltered();
@@ -283,10 +248,9 @@ void KMFilterListBox::createFilter(const QByteArray &field, const QString &value
 {
     SearchRule::Ptr newRule = SearchRule::createInstance(field, SearchRule::FuncContains, value);
 
-    MailFilter *newFilter = new MailFilter();
+    auto newFilter = new MailFilter();
     newFilter->pattern()->append(newRule);
-    newFilter->pattern()->setName(QStringLiteral("<%1>: %2").
-                                  arg(QString::fromLatin1(field), value));
+    newFilter->pattern()->setName(QStringLiteral("<%1>: %2").arg(QString::fromLatin1(field), value));
 
     FilterActionDesc *desc = MailCommon::FilterManager::filterActionDict()->value(QStringLiteral("transfer"));
     if (desc) {
@@ -304,7 +268,7 @@ void KMFilterListBox::slotUpdateFilterName()
         qCDebug(MAILCOMMON_LOG) << "Called while no filter is selected, ignoring.";
         return;
     }
-    QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
+    auto itemFilter = static_cast<QListWidgetFilterItem *>(item);
     MailCommon::MailFilter *filter = itemFilter->filter();
 
     SearchPattern *p = filter->pattern();
@@ -322,9 +286,7 @@ void KMFilterListBox::slotUpdateFilterName()
     if (filter->isAutoNaming()) {
         // auto-naming of patterns
         if (!p->isEmpty() && p->first() && !p->first()->field().trimmed().isEmpty()) {
-            shouldBeName = QStringLiteral("<%1>: %2").
-                           arg(QString::fromLatin1(p->first()->field())).
-                           arg(p->first()->contents());
+            shouldBeName = QStringLiteral("<%1>: %2").arg(QString::fromLatin1(p->first()->field()), p->first()->contents());
         } else {
             shouldBeName = QLatin1Char('<') + i18n("unnamed") + QLatin1Char('>');
         }
@@ -371,15 +333,14 @@ void KMFilterListBox::applyFilterChanged(bool closeAfterSaving)
 
 QVector<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, bool &wasCanceled) const
 {
-    Q_EMIT const_cast<KMFilterListBox *>(this)->applyWidgets();  // signals aren't const
+    Q_EMIT const_cast<KMFilterListBox *>(this)->applyWidgets(); // signals aren't const
     QVector<MailFilter *> filters;
     QStringList emptyFilters;
     QVector<MailCommon::InvalidFilterInfo> listInvalidFilters;
     const int numberOfFilter(mListWidget->count());
     for (int i = 0; i < numberOfFilter; ++i) {
-        QListWidgetFilterItem *itemFilter
-            = static_cast<QListWidgetFilterItem *>(mListWidget->item(i));
-        MailFilter *f = new MailFilter(*itemFilter->filter());   // deep copy
+        auto *itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(i));
+        auto f = new MailFilter(*itemFilter->filter()); // deep copy
 
         const QString information = f->purify();
         if (!f->isEmpty() && information.isEmpty()) {
@@ -419,8 +380,7 @@ void KMFilterListBox::slotSelectionChanged()
 void KMFilterListBox::slotSelected(int aIdx)
 {
     if (aIdx >= 0 && aIdx < mListWidget->count()) {
-        QListWidgetFilterItem *itemFilter
-            = static_cast<QListWidgetFilterItem *>(mListWidget->item(aIdx));
+        auto *itemFilter = static_cast<QListWidgetFilterItem *>(mListWidget->item(aIdx));
         MailFilter *f = itemFilter->filter();
 
         if (f) {
@@ -454,7 +414,7 @@ void KMFilterListBox::slotCopy()
 
     // make sure that all changes are written to the filter before we copy it
     Q_EMIT applyWidgets();
-    QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
+    auto itemFilter = static_cast<QListWidgetFilterItem *>(item);
 
     MailFilter *filter = itemFilter->filter();
 
@@ -463,7 +423,7 @@ void KMFilterListBox::slotCopy()
     Q_ASSERT(filter);
 
     // inserts a copy of the current filter.
-    MailFilter *copyFilter = new MailFilter(*filter);
+    auto copyFilter = new MailFilter(*filter);
     copyFilter->generateRandomIdentifier();
     copyFilter->setShortcut(QKeySequence());
 
@@ -479,23 +439,22 @@ void KMFilterListBox::slotDelete()
     }
     const bool uniqFilterSelected = (mListWidget->selectedItems().count() == 1);
 
-    QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(itemFirst);
+    auto itemFilter = static_cast<QListWidgetFilterItem *>(itemFirst);
     MailCommon::MailFilter *filter = itemFilter->filter();
-    const QString filterName = filter->pattern()->name();
-    if (uniqFilterSelected) {
-        if (KMessageBox::questionYesNo(
-                this,
-                i18n("Do you want to remove the filter \"%1\"?", filterName),
-                i18n("Remove Filter")) == KMessageBox::No) {
-            return;
-        }
-    } else {
-        if (KMessageBox::questionYesNo(
-                this,
-                i18n("Do you want to remove selected filters?"),
-                i18n("Remove Filters")) == KMessageBox::No) {
-            return;
-        }
+    const QString question =
+        uniqFilterSelected ? i18n("Do you want to remove the filter \"%1\"?", filter->pattern()->name()) : i18n("Do you want to remove selected filters?");
+    const QString dialogTitle = uniqFilterSelected ? i18n("Remove Filter") : i18n("Remove Filters");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int answer = KMessageBox::questionTwoActions(this, question, dialogTitle, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+#else
+    const int answer = KMessageBox::questionYesNo(this, question, dialogTitle, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+#else
+    if (answer == KMessageBox::No) {
+#endif
+        return;
     }
 
     const int oIdxSelItem = mListWidget->currentRow();
@@ -505,7 +464,7 @@ void KMFilterListBox::slotDelete()
 
     const QList<QListWidgetItem *> lstItems = mListWidget->selectedItems();
     for (QListWidgetItem *item : lstItems) {
-        QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
+        auto itemFilter = static_cast<QListWidgetFilterItem *>(item);
 
         MailCommon::MailFilter *filter = itemFilter->filter();
         lst << filter;
@@ -590,11 +549,9 @@ QStringList KMFilterListBox::selectedFilterId(SearchRule::RequiredPart &required
         if (mListWidget->item(i)->isSelected() && !mListWidget->item(i)->isHidden()) {
             MailFilter *filter = static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter();
             if (!filter->isEmpty()) {
-                const QString id
-                    = filter->identifier();
+                const QString id = filter->identifier();
                 listFilterId << id;
-                requiredPart = qMax(requiredPart,
-                                    static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter()->requiredPart(resource));
+                requiredPart = qMax(requiredPart, static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter()->requiredPart(resource));
             }
         }
     }
@@ -699,7 +656,7 @@ void KMFilterListBox::slotRename()
     if (!itemIsValid(item)) {
         return;
     }
-    QListWidgetFilterItem *itemFilter = static_cast<QListWidgetFilterItem *>(item);
+    auto itemFilter = static_cast<QListWidgetFilterItem *>(item);
 
     bool okPressed = false;
     MailFilter *filter = itemFilter->filter();
@@ -709,14 +666,12 @@ void KMFilterListBox::slotRename()
     Q_ASSERT(filter);
 
     // allow empty names - those will turn auto-naming on again
-    QString newName
-        = QInputDialog::getText(window(),
-                                i18n("Rename Filter"),
-                                i18n("Rename filter \"%1\" to:\n(leave the field empty for automatic naming)",
-                                     filter->pattern()->name()), /*label*/
-                                QLineEdit::Normal,
-                                filter->pattern()->name(), /* initial value */
-                                &okPressed);
+    QString newName = QInputDialog::getText(window(),
+                                            i18n("Rename Filter"),
+                                            i18n("Rename filter \"%1\" to:\n(leave the field empty for automatic naming)", filter->pattern()->name()), /*label*/
+                                            QLineEdit::Normal,
+                                            filter->pattern()->name(), /* initial value */
+                                            &okPressed);
 
     if (!okPressed) {
         return;
@@ -749,23 +704,16 @@ void KMFilterListBox::enableControls()
     const bool uniqFilterSelected = (numberOfSelectedItem == 1);
     const bool allItemSelected = (numberOfSelectedItem == numberOfElement);
 
-    mBtnUp->setEnabled(aFilterIsSelected && ((uniqFilterSelected && !theFirst)
-                                             || (!uniqFilterSelected)) && !allItemSelected);
-    mBtnDown->setEnabled(aFilterIsSelected
-                         && ((uniqFilterSelected && !theLast)
-                             || (!uniqFilterSelected)) && !allItemSelected);
+    mBtnUp->setEnabled(aFilterIsSelected && ((uniqFilterSelected && !theFirst) || (!uniqFilterSelected)) && !allItemSelected);
+    mBtnDown->setEnabled(aFilterIsSelected && ((uniqFilterSelected && !theLast) || (!uniqFilterSelected)) && !allItemSelected);
 
     mBtnCopy->setEnabled(aFilterIsSelected && uniqFilterSelected);
     mBtnDelete->setEnabled(aFilterIsSelected);
     mBtnRename->setEnabled(aFilterIsSelected && uniqFilterSelected);
 
-    mBtnTop->setEnabled(aFilterIsSelected
-                        && ((uniqFilterSelected && !theFirst)
-                            || (!uniqFilterSelected)) && !allItemSelected);
+    mBtnTop->setEnabled(aFilterIsSelected && ((uniqFilterSelected && !theFirst) || (!uniqFilterSelected)) && !allItemSelected);
 
-    mBtnBottom->setEnabled(aFilterIsSelected
-                           && ((uniqFilterSelected && !theLast)
-                               || (!uniqFilterSelected)) && !allItemSelected);
+    mBtnBottom->setEnabled(aFilterIsSelected && ((uniqFilterSelected && !theLast) || (!uniqFilterSelected)) && !allItemSelected);
     if (aFilterIsSelected) {
         mListWidget->scrollToItem(mListWidget->currentItem());
     }
@@ -785,8 +733,7 @@ void KMFilterListBox::loadFilterList(bool createDummyFilter)
 
     const QVector<MailFilter *> filters = MailCommon::FilterManager::instance()->filters();
     for (MailFilter *filter : filters) {
-        QListWidgetFilterItem *item
-            = new QListWidgetFilterItem(filter->pattern()->name(), mListWidget);
+        auto *item = new QListWidgetFilterItem(filter->pattern()->name(), mListWidget);
         item->setFilter(new MailFilter(*filter));
         mListWidget->addItem(item);
     }
@@ -815,7 +762,7 @@ void KMFilterListBox::insertFilter(MailFilter *aFilter)
     Q_ASSERT(aFilter);
     const int currentIndex = mListWidget->currentRow();
     // if mIdxSelItem < 0, QListBox::insertItem will append.
-    QListWidgetFilterItem *item = new QListWidgetFilterItem(aFilter->pattern()->name());
+    auto item = new QListWidgetFilterItem(aFilter->pattern()->name());
     item->setFilter(aFilter);
     mListWidget->insertItem(currentIndex, item);
     mListWidget->clearSelection();
@@ -832,8 +779,7 @@ void KMFilterListBox::insertFilter(MailFilter *aFilter)
 
 void KMFilterListBox::appendFilter(MailFilter *aFilter)
 {
-    QListWidgetFilterItem *item
-        = new QListWidgetFilterItem(aFilter->pattern()->name(), mListWidget);
+    auto *item = new QListWidgetFilterItem(aFilter->pattern()->name(), mListWidget);
 
     item->setFilter(aFilter);
     mListWidget->addItem(item);
@@ -870,7 +816,7 @@ void QListWidgetFilterItem::setFilter(MailCommon::MailFilter *filter)
     setCheckState(filter->isEnabled() ? Qt::Checked : Qt::Unchecked);
 }
 
-MailCommon::MailFilter *QListWidgetFilterItem::filter()
+MailCommon::MailFilter *QListWidgetFilterItem::filter() const
 {
     return mFilter;
 }
