@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,8 +17,6 @@
 #include <Akonadi/AgentInstance>
 #include <Akonadi/AgentManager>
 
-#include <KMime/KMimeMessage>
-
 #include <KConfigGroup>
 #include <QCheckBox>
 #include <QDialogButtonBox>
@@ -26,7 +24,10 @@
 #include <QListWidget>
 
 using namespace MailCommon;
-
+namespace
+{
+static const char myAccountConfigOrderDialogName[] = "AccountConfigOrderDialog";
+}
 struct InstanceStruct {
     QString name;
     QIcon icon;
@@ -236,7 +237,7 @@ void AccountConfigOrderDialog::slotOk()
 
 void AccountConfigOrderDialog::readConfig()
 {
-    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
+    KConfigGroup accountConfigDialog(d->mSettings->config(), myAccountConfigOrderDialogName);
     const QSize size = accountConfigDialog.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -245,7 +246,7 @@ void AccountConfigOrderDialog::readConfig()
 
 void AccountConfigOrderDialog::writeConfig()
 {
-    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
+    KConfigGroup accountConfigDialog(d->mSettings->config(), myAccountConfigOrderDialogName);
     accountConfigDialog.writeEntry("Size", size());
     accountConfigDialog.sync();
 }
