@@ -1,48 +1,30 @@
 /*
-  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "foldercollectionmonitor.h"
-#include "util/mailutil.h"
+#include "collectionpage/attributes/expirecollectionattribute.h"
 #include "foldersettings.h"
 #include "mailcommon_debug.h"
-#include <ChangeRecorder>
-#include <Collection>
-#include <CollectionFetchScope>
-#include <EntityTreeModel>
-#include <Item>
-#include <ItemDeleteJob>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include "collectionpage/attributes/expirecollectionattribute.h"
-#include <Akonadi/KMime/MessageParts>
-#include <AkonadiCore/entityannotationsattribute.h>
-
-#include <KMime/KMimeMessage>
+#include "util/mailutil.h"
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/EntityAnnotationsAttribute>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Item>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/MessageParts>
 
 using namespace MailCommon;
 
 class MailCommon::FolderCollectionMonitorPrivate
 {
 public:
-    FolderCollectionMonitorPrivate()
-    {
-    }
-
     Akonadi::ChangeRecorder *mMonitor = nullptr;
 };
 
@@ -67,10 +49,7 @@ FolderCollectionMonitor::FolderCollectionMonitor(Akonadi::Session *session, QObj
     d->mMonitor->itemFetchScope().fetchAttribute<Akonadi::EntityAnnotationsAttribute>(true);
 }
 
-FolderCollectionMonitor::~FolderCollectionMonitor()
-{
-    delete d;
-}
+FolderCollectionMonitor::~FolderCollectionMonitor() = default;
 
 Akonadi::ChangeRecorder *FolderCollectionMonitor::monitor() const
 {
@@ -89,37 +68,29 @@ void FolderCollectionMonitor::expireAllCollection(const QAbstractItemModel *mode
     const int rowCount = model->rowCount(parentIndex);
     for (int row = 0; row < rowCount; ++row) {
         const QModelIndex index = model->index(row, 0, parentIndex);
-        const Akonadi::Collection collection
-            = model->data(
-                  index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const auto collection = model->data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (!collection.isValid() || Util::isVirtualCollection(collection)) {
             continue;
         }
 
-        bool mustDeleteExpirationAttribute = false;
-        MailCommon::ExpireCollectionAttribute *attr
-            = MailCommon::Util::expirationCollectionAttribute(
-                  collection, mustDeleteExpirationAttribute);
-
-        if (attr->isAutoExpire()) {
-            MailCommon::Util::expireOldMessages(collection, immediate);
+        const auto *attr = collection.attribute<MailCommon::ExpireCollectionAttribute>();
+        if (attr) {
+            if (attr->isAutoExpire()) {
+                MailCommon::Util::expireOldMessages(collection, immediate);
+            }
         }
 
         if (model->rowCount(index) > 0) {
             expireAllCollection(model, immediate, index);
         }
-
-        if (mustDeleteExpirationAttribute) {
-            delete attr;
-        }
     }
 }
 
 void FolderCollectionMonitor::expunge(const Akonadi::Collection &col, bool sync)
 {
     if (col.isValid()) {
-        Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(col, this);
+        auto job = new Akonadi::ItemDeleteJob(col, this);
         connect(job, &Akonadi::ItemDeleteJob::result, this, &FolderCollectionMonitor::slotDeleteJob);
         if (sync) {
             job->exec();
