@@ -1,56 +1,31 @@
 /*
- * Copyright (c) 2004 Carsten Burghardt <burghardt@kde.org>
- * Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2004 Carsten Burghardt <burghardt@kde.org>
+ * SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  In addition, as a special exception, the copyright holders give
- *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
- *  combinations including the two.  You must obey the GNU General
- *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
- *  your version of the file, but you are not obligated to do so.  If
- *  you do not wish to do so, delete this exception statement from
- *  your version.
+ *  SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include "folderrequester.h"
 #include "folderselectiondialog.h"
-#include "util/mailutil.h"
 #include "kernel/mailkernel.h"
+#include "util/mailutil.h"
+#include <Akonadi/CollectionFetchJob>
 #include <Libkdepim/LineEditCatchReturnKey>
-#include <CollectionFetchJob>
 
-#include <QPointer>
-#include <QLineEdit>
 #include <KLocalizedString>
 #include <QIcon>
+#include <QLineEdit>
+#include <QPointer>
 
 #include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QToolButton>
 
-namespace MailCommon {
-class FolderRequesterPrivate
+using namespace MailCommon;
+
+class MailCommon::FolderRequesterPrivate
 {
 public:
-    FolderRequesterPrivate()
-    {
-    }
-
     Akonadi::Collection mCollection;
     QLineEdit *mEdit = nullptr;
     QString mSelectFolderTitleDialog;
@@ -63,8 +38,8 @@ FolderRequester::FolderRequester(QWidget *parent)
     : QWidget(parent)
     , d(new MailCommon::FolderRequesterPrivate)
 {
-    QHBoxLayout *hlay = new QHBoxLayout(this);
-    hlay->setContentsMargins(0, 0, 0, 0);
+    auto hlay = new QHBoxLayout(this);
+    hlay->setContentsMargins({});
 
     d->mEdit = new QLineEdit(this);
     d->mEdit->setPlaceholderText(i18n("Select Folder"));
@@ -72,13 +47,12 @@ FolderRequester::FolderRequester(QWidget *parent)
     d->mEdit->setReadOnly(true);
     hlay->addWidget(d->mEdit);
 
-    QToolButton *button = new QToolButton(this);
+    auto button = new QToolButton(this);
     button->setIcon(QIcon::fromTheme(QStringLiteral("folder")));
     hlay->addWidget(button);
     connect(button, &QToolButton::clicked, this, &FolderRequester::slotOpenDialog);
 
-    setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
-                              QSizePolicy::Fixed));
+    setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
     setFocusPolicy(Qt::StrongFocus);
 }
 
@@ -107,10 +81,7 @@ void FolderRequester::slotOpenDialog()
 }
 
 //-----------------------------------------------------------------------------
-FolderRequester::~FolderRequester()
-{
-    delete d;
-}
+FolderRequester::~FolderRequester() = default;
 
 Akonadi::Collection FolderRequester::collection() const
 {
@@ -132,14 +103,13 @@ void FolderRequester::setCollection(const Akonadi::Collection &collection, bool
     d->mCollection = collection;
     if (d->mCollection.isValid()) {
         if (fetchCollection) {
-            Akonadi::CollectionFetchJob *job
-                = new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base, this);
+            auto *job = new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base, this);
 
             connect(job, &Akonadi::CollectionFetchJob::result, this, &FolderRequester::slotCollectionsReceived);
         } else {
             setCollectionFullPath(d->mCollection);
         }
-    } else if (!d->mMustBeReadWrite) {   // the Local Folders root node was selected
+    } else if (!d->mMustBeReadWrite) { // the Local Folders root node was selected
         d->mEdit->setText(i18n("Local Folders"));
     }
 
@@ -207,4 +177,3 @@ void FolderRequester::setSelectFolderTitleDialog(const QString &title)
 {
     d->mSelectFolderTitleDialog = title;
 }
-} // namespace MailCommon
