@@ -1,19 +1,17 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "foldersettings.h"
 #include "kernel/mailkernel.h"
-#include "mailcommon_debug.h"
-#include "util/mailutil.h"
 #include "util/resourcereadconfigfile.h"
 #include <Akonadi/CollectionModifyJob>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/NewMailNotifierAttribute>
+#include <Akonadi/NewMailNotifierAttribute>
 #include <PimCommon/PimUtil>
 
 using namespace Akonadi;
@@ -36,7 +34,7 @@ QSharedPointer<FolderSettings> FolderSettings::forCollection(const Akonadi::Coll
 
     QSharedPointer<FolderSettings> sptr = fcMap.value(coll.id());
 
-    if (!sptr) {
+    if (sptr.isNull()) {
         sptr = QSharedPointer<FolderSettings>(new FolderSettings(coll, writeConfig));
         fcMap.insert(coll.id(), sptr);
     } else {
@@ -219,6 +217,9 @@ bool FolderSettings::isValid() const
 void FolderSettings::writeConfig() const
 {
     const QString res = resource();
+    if (res.isEmpty()) {
+        return;
+    }
     KConfigGroup configGroup(KernelIf->config(), configGroupName(mCollection));
 
     if (mMailingListEnabled) {
@@ -322,9 +323,10 @@ QString FolderSettings::resource() const
     const QString resource = mCollection.resource();
     if (resource.isEmpty()) {
         const Collection col = CommonKernel->collectionFromId(mCollection.id());
-        Q_ASSERT(col.isValid());
-        Q_ASSERT(!col.resource().isEmpty());
-        return col.resource();
+        if (col.isValid()) {
+            Q_ASSERT(!col.resource().isEmpty());
+            return col.resource();
+        }
     }
     return resource;
 }
@@ -382,7 +384,7 @@ QString FolderSettings::mailingListPostAddress() const
             }
         }
     }
-    return QString();
+    return {};
 }
 
 void FolderSettings::setMailingListEnabled(bool enabled)
