@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,8 +19,10 @@
 #include <KMessageBox>
 #include <QMenu>
 
+#include <QActionGroup>
 #include <QHeaderView>
 #include <QMouseEvent>
+#include <kwidgetsaddons_version.h>
 
 using namespace MailCommon;
 
@@ -36,9 +38,7 @@ FolderTreeView::FolderTreeView(KXMLGUIClient *xmlGuiClient, QWidget *parent, boo
     init(showUnreadCount);
 }
 
-FolderTreeView::~FolderTreeView()
-{
-}
+FolderTreeView::~FolderTreeView() = default;
 
 void FolderTreeView::disableSaveConfig()
 {
@@ -470,15 +470,23 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
     // warn user that going to next folder - but keep track of
     // whether he wishes to be notified again in "AskNextFolder"
     // parameter (kept in the config file for kmail)
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int result = KMessageBox::questionTwoActions(const_cast<FolderTreeView *>(this),
+#else
     const int result = KMessageBox::questionYesNo(const_cast<FolderTreeView *>(this),
-                                                  i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-                                                  i18n("Go to Next Unread Message"),
-                                                  KGuiItem(i18n("Go To")),
-                                                  KGuiItem(i18n("Do Not Go To")), // defaults
-                                                  QStringLiteral(":kmail_AskNextFolder"),
-                                                  KMessageBox::Option());
+#endif
+                                                       i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
+                                                       i18n("Go to Next Unread Message"),
+                                                       KGuiItem(i18n("Go To")),
+                                                       KGuiItem(i18n("Do Not Go To")), // defaults
+                                                       QStringLiteral(":kmail_AskNextFolder"),
+                                                       KMessageBox::Option());
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    return result == KMessageBox::ButtonCode::PrimaryAction;
+#else
     return result == KMessageBox::Yes;
+#endif
 }
 
 bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &index, FolderTreeView::Move move, bool confirm)
@@ -512,14 +520,23 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
                         // warn user that going to next folder - but keep track of
                         // whether he wishes to be notified again in "AskNextFolder"
                         // parameter (kept in the config file for kmail)
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                        if (KMessageBox::questionTwoActions(this,
+#else
                         if (KMessageBox::questionYesNo(this,
-                                                       i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-                                                       i18n("Go to Next Unread Message"),
-                                                       KGuiItem(i18n("Go To")),
-                                                       KGuiItem(i18n("Do Not Go To")), // defaults
-                                                       QStringLiteral(":kmail_AskNextFolder"),
-                                                       KMessageBox::Option())
+
+#endif
+                                                            i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
+                                                            i18n("Go to Next Unread Message"),
+                                                            KGuiItem(i18n("Go To")),
+                                                            KGuiItem(i18n("Do Not Go To")), // defaults
+                                                            QStringLiteral(":kmail_AskNextFolder"),
+                                                            KMessageBox::Option())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                            == KMessageBox::ButtonCode::SecondaryAction) {
+#else
                             == KMessageBox::No) {
+#endif
                             return true; // assume selected (do not continue looping)
                         }
 
@@ -540,7 +557,7 @@ Akonadi::Collection FolderTreeView::currentFolder() const
         const auto collection = current.model()->data(current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         return collection;
     }
-    return Akonadi::Collection();
+    return {};
 }
 
 void FolderTreeView::mousePressEvent(QMouseEvent *e)
@@ -575,6 +592,13 @@ void FolderTreeView::keyboardSearch(const QString &)
     // either because KMail has one-letter keyboard shortcuts.
 }
 
+void FolderTreeView::setEnableDragDrop(bool enabled)
+{
+#ifndef QT_NO_DRAGANDDROP
+    setDragDropMode(enabled ? QAbstractItemView::DragDrop : QAbstractItemView::NoDragDrop);
+#endif
+}
+
 QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
 {
     // if we have children, return first child
@@ -591,7 +615,7 @@ QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
     }
 
     if (!parent.isValid()) { // our parent is the tree root and we have no siblings
-        return QModelIndex(); // we reached the bottom of the tree
+        return {}; // we reached the bottom of the tree
     }
 
     // We are the last child, the next index to check is our uncle, parent's first sibling
@@ -616,7 +640,7 @@ QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
         grandParent = model()->parent(currentParent);
     }
 
-    return QModelIndex(); // nothing found -> end of tree
+    return {}; // nothing found -> end of tree
 }
 
 QModelIndex FolderTreeView::lastChild(const QModelIndex &current) const
@@ -656,7 +680,7 @@ QModelIndex FolderTreeView::nextUnreadCollection(const QModelIndex &current, Sea
         }
 
         if (!index.isValid()) { // reach end or top of the model
-            return QModelIndex();
+            return {};
         }
 
         // check if the index is a collection
@@ -672,5 +696,5 @@ QModelIndex FolderTreeView::nextUnreadCollection(const QModelIndex &current, Sea
         }
     }
 
-    return QModelIndex(); // no unread collection found
+    return {}; // no unread collection found
 }
