@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,6 @@
 #include "foldertreeview.h"
 #include "hierarchicalfoldermatcher_p.h"
 #include "kernel/mailkernel.h"
-#include "util/mailutil.h"
 
 #include <PimCommon/PimUtil>
 #include <PimCommonAkonadi/ImapAclAttribute>
@@ -31,6 +30,7 @@
 
 #include <KLocalizedString>
 
+#include <QApplication>
 #include <QFontDatabase>
 #include <QHeaderView>
 #include <QKeyEvent>
@@ -39,9 +39,9 @@
 #include <QPointer>
 #include <QVBoxLayout>
 
-namespace MailCommon
-{
-class Q_DECL_HIDDEN FolderTreeWidget::FolderTreeWidgetPrivate
+using namespace MailCommon;
+
+class Q_DECL_HIDDEN MailCommon::FolderTreeWidget::FolderTreeWidgetPrivate
 {
 public:
     QString filter;
@@ -126,6 +126,9 @@ FolderTreeWidget::FolderTreeWidget(QWidget *parent,
         d->filterFolderLineEdit->hide();
         setAttribute(Qt::WA_InputMethodEnabled);
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &FolderTreeWidget::slotGeneralPaletteChanged);
+#endif
 }
 
 FolderTreeWidget::~FolderTreeWidget() = default;
@@ -198,13 +201,13 @@ Akonadi::Collection FolderTreeWidget::selectedCollection() const
     if (d->folderTreeView->selectionMode() == QAbstractItemView::SingleSelection) {
         Akonadi::Collection::List lstCollection = selectedCollections();
         if (lstCollection.isEmpty()) {
-            return Akonadi::Collection();
+            return {};
         } else {
             return lstCollection.at(0);
         }
     }
 
-    return Akonadi::Collection();
+    return {};
 }
 
 Akonadi::Collection::List FolderTreeWidget::selectedCollections() const
@@ -381,4 +384,13 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
     }
     return false;
 }
+
+bool FolderTreeWidget::event(QEvent *e)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() == QEvent::ApplicationPaletteChange) {
+        slotGeneralPaletteChanged();
+    }
+#endif
+    return QWidget::event(e);
 }
