@@ -5,7 +5,6 @@
  */
 
 #include "jobscheduler.h"
-#include "mailcommon_debug.h"
 using namespace MailCommon;
 
 ScheduledTask::ScheduledTask(const Akonadi::Collection &folder, bool immediate)
@@ -14,10 +13,18 @@ ScheduledTask::ScheduledTask(const Akonadi::Collection &folder, bool immediate)
 {
 }
 
-ScheduledTask::~ScheduledTask()
+Akonadi::Collection ScheduledTask::folder() const
 {
+    return mCurrentFolder;
 }
 
+bool ScheduledTask::isImmediate() const
+{
+    return mImmediate;
+}
+
+ScheduledTask::~ScheduledTask() = default;
+
 JobScheduler::JobScheduler(QObject *parent)
     : QObject(parent)
     , mTimer(this)
@@ -217,6 +224,4 @@ ScheduledJob::ScheduledJob(const Akonadi::Collection &folder, bool immediate)
     mSrcFolder = folder;
 }
 
-ScheduledJob::~ScheduledJob()
-{
-}
+ScheduledJob::~ScheduledJob() = default;
