@@ -1,52 +1,35 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "daterulewidgethandler.h"
-#include "search/searchpattern.h"
 
 #include <KDateComboBox>
 #include <KLocalizedString>
 
+#include <KLazyLocalizedString>
+#include <QComboBox>
 #include <QDate>
 #include <QObject>
 #include <QStackedWidget>
-#include <QComboBox>
-
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} DateFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is equal to")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")      },
-    { SearchRule::FuncIsGreater, I18N_NOOP("is after")     },
-    { SearchRule::FuncIsLessOrEqual, I18N_NOOP("is before or equal to") },
-    { SearchRule::FuncIsLess, I18N_NOOP("is before")        },
-    { SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is after or equal to") }
-};
-static const int DateFunctionCount
-    = sizeof(DateFunctions) / sizeof(*DateFunctions);
+    const KLazyLocalizedString displayName;
+} DateFunctions[] = {{SearchRule::FuncEquals, kli18n("is equal to")},
+                     {SearchRule::FuncNotEqual, kli18n("is not equal to")},
+                     {SearchRule::FuncIsGreater, kli18n("is after")},
+                     {SearchRule::FuncIsLessOrEqual, kli18n("is before or equal to")},
+                     {SearchRule::FuncIsLess, kli18n("is before")},
+                     {SearchRule::FuncIsGreaterOrEqual, kli18n("is after or equal to")}};
+static const int DateFunctionCount = sizeof(DateFunctions) / sizeof(*DateFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *DateRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *DateRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
@@ -56,11 +39,10 @@ QWidget *DateRuleWidgetHandler::createFunctionWidget(
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("dateRuleFuncCombo"));
     for (int i = 0; i < DateFunctionCount; ++i) {
-        funcCombo->addItem(i18n(DateFunctions[i].displayName));
+        funcCombo->addItem(DateFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -72,18 +54,16 @@ QWidget *DateRuleWidgetHandler::createValueWidget(int number, QStackedWidget *va
         return nullptr;
     }
 
-    KDateComboBox *dateCombo = new KDateComboBox(valueStack);
+    auto dateCombo = new KDateComboBox(valueStack);
     dateCombo->setObjectName(QStringLiteral("KDateComboBox"));
     dateCombo->setOptions(KDateComboBox::SelectDate | KDateComboBox::DatePicker | KDateComboBox::DateKeywords);
-    QObject::connect(dateCombo, SIGNAL(dateChanged(QDate)),
-                     receiver, SLOT(slotValueChanged()));
+    QObject::connect(dateCombo, SIGNAL(dateChanged(QDate)), receiver, SLOT(slotValueChanged()));
     return dateCombo;
 }
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function DateRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function DateRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("dateRuleFuncCombo"));
 
@@ -115,7 +95,7 @@ QString DateRuleWidgetHandler::currentValue(const QStackedWidget *valueStack) co
         return dateInput->date().toString(Qt::ISODate);
     }
 
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -123,7 +103,7 @@ QString DateRuleWidgetHandler::currentValue(const QStackedWidget *valueStack) co
 QString DateRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -134,7 +114,7 @@ QString DateRuleWidgetHandler::value(const QByteArray &field, const QStackedWidg
 QString DateRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -161,7 +141,7 @@ void DateRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidget
     }
 
     // reset the value widget
-    KDateComboBox *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
+    auto *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
 
     if (dateInput) {
         dateInput->blockSignals(true);
@@ -204,7 +184,7 @@ bool DateRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidge
     // set the value
     const QString value = rule->contents();
 
-    KDateComboBox *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
+    auto *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
 
     if (dateInput) {
         dateInput->blockSignals(true);
@@ -227,7 +207,7 @@ bool DateRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *func
     functionStack->setCurrentWidget(functionStack->findChild<QWidget *>(QStringLiteral("dateRuleFuncCombo")));
 
     // raise the correct value widget
-    KDateComboBox *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
+    auto *dateInput = valueStack->findChild<KDateComboBox *>(QStringLiteral("KDateComboBox"));
 
     if (dateInput) {
         valueStack->setCurrentWidget(dateInput);
