@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,30 +11,30 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 
+#include <KLazyLocalizedString>
 #include <QComboBox>
 #include <QLabel>
 #include <QStackedWidget>
-
 using namespace MailCommon;
 
 // also see SearchRule::matches() and SearchRule::Function
 // if you change the following strings!
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} HeaderFunctions[] = {{SearchRule::FuncContains, I18N_NOOP("contains")},
-                       {SearchRule::FuncContainsNot, I18N_NOOP("does not contain")},
-                       {SearchRule::FuncEquals, I18N_NOOP("equals")},
-                       {SearchRule::FuncNotEqual, I18N_NOOP("does not equal")},
-                       {SearchRule::FuncStartWith, I18N_NOOP("starts with")},
-                       {SearchRule::FuncNotStartWith, I18N_NOOP("does not start with")},
-                       {SearchRule::FuncEndWith, I18N_NOOP("ends with")},
-                       {SearchRule::FuncNotEndWith, I18N_NOOP("does not end with")},
+    const KLazyLocalizedString displayName;
+} HeaderFunctions[] = {{SearchRule::FuncContains, kli18n("contains")},
+                       {SearchRule::FuncContainsNot, kli18n("does not contain")},
+                       {SearchRule::FuncEquals, kli18n("equals")},
+                       {SearchRule::FuncNotEqual, kli18n("does not equal")},
+                       {SearchRule::FuncStartWith, kli18n("starts with")},
+                       {SearchRule::FuncNotStartWith, kli18n("does not start with")},
+                       {SearchRule::FuncEndWith, kli18n("ends with")},
+                       {SearchRule::FuncNotEndWith, kli18n("does not end with")},
 
-                       {SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.")},
-                       {SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.")},
-                       {SearchRule::FuncIsInAddressbook, I18N_NOOP("is in address book")},
-                       {SearchRule::FuncIsNotInAddressbook, I18N_NOOP("is not in address book")}};
+                       {SearchRule::FuncRegExp, kli18n("matches regular expr.")},
+                       {SearchRule::FuncNotRegExp, kli18n("does not match reg. expr.")},
+                       {SearchRule::FuncIsInAddressbook, kli18n("is in address book")},
+                       {SearchRule::FuncIsNotInAddressbook, kli18n("is not in address book")}};
 static const int HeadersFunctionCount = sizeof(HeaderFunctions) / sizeof(*HeaderFunctions);
 
 //---------------------------------------------------------------------------
@@ -50,7 +50,7 @@ QWidget *HeadersRuleWidgetHandler::createFunctionWidget(int number, QStackedWidg
     funcCombo->setObjectName(QStringLiteral("headerRuleFuncCombo"));
     for (int i = 0; i < HeadersFunctionCount; ++i) {
         if (!(isBalooSearch && (HeaderFunctions[i].id == SearchRule::FuncIsInAddressbook || HeaderFunctions[i].id == SearchRule::FuncIsNotInAddressbook))) {
-            funcCombo->addItem(i18n(HeaderFunctions[i].displayName));
+            funcCombo->addItem(HeaderFunctions[i].displayName.toString());
         }
     }
     funcCombo->adjustSize();
@@ -117,7 +117,7 @@ QString HeadersRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
     }
 
     // or anything else, like addressbook
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -125,7 +125,7 @@ QString HeadersRuleWidgetHandler::currentValue(const QStackedWidget *valueStack,
 QString HeadersRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
     SearchRule::Function func = currentFunction(functionStack);
     if (func == SearchRule::FuncIsInAddressbook) {
@@ -142,7 +142,7 @@ QString HeadersRuleWidgetHandler::value(const QByteArray &field, const QStackedW
 QString HeadersRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     SearchRule::Function func = currentFunction(functionStack);
