@@ -1,25 +1,24 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGERULEWIDGETHANDLER_H
-#define MESSAGERULEWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class MessageRuleWidgetHandler : public MailCommon::RuleWidgetHandler
 {
 public:
-    MessageRuleWidgetHandler() : MailCommon::RuleWidgetHandler()
+    MessageRuleWidgetHandler()
+        : MailCommon::RuleWidgetHandler()
     {
     }
 
-    ~MessageRuleWidgetHandler()
-    {
-    }
+    ~MessageRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -44,5 +43,3 @@ private:
     QString currentValue(const QStackedWidget *valueStack, SearchRule::Function func) const;
 };
 }
-
-#endif // MESSAGERULEWIDGETHANDLER_H
