@@ -1,24 +1,52 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "statusrulewidgethandler.h"
-#include "search/searchrule/searchrulestatus.h"
 
+#include <KLazyLocalizedString>
 #include <QComboBox>
 #include <QIcon>
 #include <QStackedWidget>
-
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} StatusFunctions[] = {{SearchRule::FuncContains, I18N_NOOP("is")}, {SearchRule::FuncContainsNot, I18N_NOOP("is not")}};
+    const KLazyLocalizedString displayName;
+} StatusFunctions[] = {{SearchRule::FuncContains, kli18n("is")}, {SearchRule::FuncContainsNot, kli18n("is not")}};
 static const int StatusFunctionCount = sizeof(StatusFunctions) / sizeof(*StatusFunctions);
 
+struct MessageStatusInfo {
+    const KLazyLocalizedString text;
+    const char *icon;
+};
+
+// If you change the ordering here; also do it in the enum below
+static const MessageStatusInfo StatusValues[] = {
+    {kli18nc("message status", "Important"), "emblem-important"},
+    {kli18nc("message status", "Action Item"), "mail-task"},
+    {kli18nc("message status", "Unread"), "mail-unread"},
+    {kli18nc("message status", "Read"), "mail-read"},
+    {kli18nc("message status", "Deleted"), "mail-deleted"},
+    {kli18nc("message status", "Replied"), "mail-replied"},
+    {kli18nc("message status", "Forwarded"), "mail-forwarded"},
+    {kli18nc("message status", "Queued"), "mail-queued"},
+    {kli18nc("message status", "Sent"), "mail-sent"},
+    {kli18nc("message status", "Watched"), "mail-thread-watch"},
+    {kli18nc("message status", "Ignored"), "mail-thread-ignored"},
+    {kli18nc("message status", "Spam"), "mail-mark-junk"},
+    {kli18nc("message status", "Ham"), "mail-mark-notjunk"},
+    {kli18nc("message status", "Has Attachment"), "mail-attachment"} // must be last
+};
+
+static const int StatusValueCount = sizeof(StatusValues) / sizeof(MessageStatusInfo);
+// we want to show all status entries in the quick search bar, but only the
+// ones up to attachment in the search/filter dialog, because there the
+// attachment case is handled separately.
+static const int StatusValueCountWithoutHidden = StatusValueCount - 1;
+
 //---------------------------------------------------------------------------
 
 QWidget *StatusRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
@@ -31,7 +59,7 @@ QWidget *StatusRuleWidgetHandler::createFunctionWidget(int number, QStackedWidge
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("statusRuleFuncCombo"));
     for (int i = 0; i < StatusFunctionCount; ++i) {
-        funcCombo->addItem(i18n(StatusFunctions[i].displayName));
+        funcCombo->addItem(StatusFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
     QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
@@ -49,11 +77,11 @@ QWidget *StatusRuleWidgetHandler::createValueWidget(int number, QStackedWidget *
     auto statusCombo = new QComboBox(valueStack);
     statusCombo->setMinimumWidth(50);
     statusCombo->setObjectName(QStringLiteral("statusRuleValueCombo"));
-    for (int i = 0; i < MailCommon::StatusValueCountWithoutHidden; ++i) {
-        if (MailCommon::StatusValues[i].icon != nullptr) {
-            statusCombo->addItem(QIcon::fromTheme(QLatin1String(MailCommon::StatusValues[i].icon)), i18nc("message status", MailCommon::StatusValues[i].text));
+    for (int i = 0; i < StatusValueCountWithoutHidden; ++i) {
+        if (StatusValues[i].icon != nullptr) {
+            statusCombo->addItem(QIcon::fromTheme(QLatin1String(StatusValues[i].icon)), StatusValues[i].text.toString());
         } else {
-            statusCombo->addItem(i18nc("message status", MailCommon::StatusValues[i].text));
+            statusCombo->addItem(StatusValues[i].text.toString());
         }
     }
     statusCombo->adjustSize();
@@ -103,14 +131,14 @@ int StatusRuleWidgetHandler::currentStatusValue(const QStackedWidget *valueStack
 QString StatusRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     const int status = currentStatusValue(valueStack);
     if (status != -1) {
-        return QString::fromLatin1(MailCommon::StatusValues[status].text);
+        return StatusValues[status].text.untranslatedText();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -119,14 +147,14 @@ QString StatusRuleWidgetHandler::value(const QByteArray &field, const QStackedWi
 QString StatusRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     const int status = currentStatusValue(valueStack);
     if (status != -1) {
-        return i18nc("message status", MailCommon::StatusValues[status].text);
+        return StatusValues[status].text.toString();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -194,8 +222,8 @@ bool StatusRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWid
     // set the value
     const QString value = rule->contents();
     int valueIndex = 0;
-    for (; valueIndex < MailCommon::StatusValueCountWithoutHidden; ++valueIndex) {
-        if (value == QString::fromLatin1(MailCommon::StatusValues[valueIndex].text)) {
+    for (; valueIndex < StatusValueCountWithoutHidden; ++valueIndex) {
+        if (value == StatusValues[valueIndex].text.untranslatedText()) {
             break;
         }
     }
@@ -204,7 +232,7 @@ bool StatusRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWid
 
     if (statusCombo) {
         statusCombo->blockSignals(true);
-        if (valueIndex < MailCommon::StatusValueCountWithoutHidden) {
+        if (valueIndex < StatusValueCountWithoutHidden) {
             statusCombo->setCurrentIndex(valueIndex);
         } else {
             statusCombo->setCurrentIndex(0);
