@@ -1,45 +1,40 @@
-/***************************************************************************
- *   snippet feature from kdevelop/plugins/snippet/                        *
- *                                                                         *
- *   Copyright (C) 2007 by Robert Gruber                                   *
- *   rgruber@users.sourceforge.net                                         *
- *   Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>                    *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+  snippet feature from kdevelop/plugins/snippet/
+
+  SPDX-FileCopyrightText: 2007 Robert Gruber <rgruber@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "snippetdialog.h"
 #include "snippetwidget.h"
 
-#include <MessageComposer/ConvertSnippetVariableMenu>
-#include <KPIMTextEdit/PlainTextEditor>
 #include <KActionCollection>
-#include <QDialog>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <MessageComposer/ConvertSnippetVariableMenu>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace MailCommon;
-namespace {
-static const char myConfigGroupName[] = "SnippetDialog";
+namespace
+{
+static const char mySnippetDialogConfigGroupName[] = "SnippetDialog";
 }
 SnippetDialog::SnippetDialog(KActionCollection *actionCollection, bool inGroupMode, QWidget *parent)
     : QDialog(parent)
     , mActionCollection(actionCollection)
+    , mSnippetWidget(new SnippetWidget(this))
     , mInGroupMode(inGroupMode)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
-    mSnippetWidget = new SnippetWidget(this);
 
     mainLayout->addWidget(mSnippetWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -68,13 +63,13 @@ SnippetDialog::~SnippetDialog()
 
 void SnippetDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySnippetDialogConfigGroupName);
     group.writeEntry("Size", size());
 }
 
 void SnippetDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySnippetDialogConfigGroupName);
     const QSize sizeDialog = group.readEntry("Size", QSize(300, 350));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
