@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -24,7 +24,6 @@ public:
 private:
     void writeConfig();
     void readConfig();
-    SnippetSelectAttachmentWidget *mAttachmentWidget = nullptr;
+    SnippetSelectAttachmentWidget *const mAttachmentWidget;
 };
 }
-
