@@ -2,7 +2,7 @@
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -35,7 +35,7 @@ public:
     {
     }
 
-    QModelIndex currentGroupIndex() const;
+    Q_REQUIRED_RESULT QModelIndex currentGroupIndex() const;
 
     void selectionChanged();
     void dndDone();
@@ -95,7 +95,7 @@ public:
 QModelIndex SnippetsManager::SnippetsManagerPrivate::currentGroupIndex() const
 {
     if (mSelectionModel->selectedIndexes().isEmpty()) {
-        return QModelIndex();
+        return {};
     }
 
     const QModelIndex index = mSelectionModel->selectedIndexes().first();
@@ -504,7 +504,7 @@ QString SnippetsManager::SnippetsManagerPrivate::replaceVariables(const QString
                         variableValue = dlg->variableValue();
                     } else {
                         delete dlg;
-                        return QString();
+                        return {};
                     }
                     delete dlg;
                 } else {
@@ -675,7 +675,7 @@ bool SnippetsManager::snippetGroupSelected() const
 QString SnippetsManager::selectedName() const
 {
     if (d->mSelectionModel->selectedIndexes().isEmpty()) {
-        return QString();
+        return {};
     }
 
     return d->mSelectionModel->selectedIndexes().first().data(SnippetsModel::NameRole).toString();
