@@ -1,35 +1,23 @@
 /*
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net,
-    Author: Tobias Koenig <tokoe@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "snippetsmodel.h"
 
-#include <KMessageBox>
-#include <KLocalizedString>
-#include <QMimeData>
-#include <QDataStream>
-#include <QStringList>
-#include <QDebug>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <QDataStream>
+#include <QIODevice>
+#include <QMimeData>
+#include <QStringList>
+#include <kwidgetsaddons_version.h>
 
 using namespace MailCommon;
 
@@ -55,10 +43,10 @@ public:
 
     void appendChild(SnippetItem *child);
     void removeChild(SnippetItem *child);
-    SnippetItem *child(int row) const;
+    Q_REQUIRED_RESULT SnippetItem *child(int row) const;
     Q_REQUIRED_RESULT int childCount() const;
     Q_REQUIRED_RESULT int row() const;
-    SnippetItem *parent() const;
+    Q_REQUIRED_RESULT SnippetItem *parent() const;
 
     Q_REQUIRED_RESULT QString subject() const;
     void setSubject(const QString &subject);
@@ -262,7 +250,7 @@ bool SnippetsModel::setData(const QModelIndex &index, const QVariant &value, int
         return false;
     }
 
-    SnippetItem *item = static_cast<SnippetItem *>(index.internalPointer());
+    auto item = static_cast<SnippetItem *>(index.internalPointer());
     Q_ASSERT(item);
 
     switch (role) {
@@ -310,10 +298,10 @@ bool SnippetsModel::setData(const QModelIndex &index, const QVariant &value, int
 QVariant SnippetsModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
-    SnippetItem *item = static_cast<SnippetItem *>(index.internalPointer());
+    auto item = static_cast<SnippetItem *>(index.internalPointer());
 
     switch (role) {
     case Qt::DisplayRole:
@@ -340,7 +328,7 @@ QVariant SnippetsModel::data(const QModelIndex &index, int role) const
         return item->attachment();
     }
 
-    return QVariant();
+    return {};
 }
 
 Qt::ItemFlags SnippetsModel::flags(const QModelIndex &index) const
@@ -360,7 +348,7 @@ Qt::ItemFlags SnippetsModel::flags(const QModelIndex &index) const
 QModelIndex SnippetsModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (!hasIndex(row, column, parent)) {
-        return QModelIndex();
+        return {};
     }
 
     SnippetItem *parentItem = nullptr;
@@ -375,21 +363,21 @@ QModelIndex SnippetsModel::index(int row, int column, const QModelIndex &parent)
     if (childItem) {
         return createIndex(row, column, childItem);
     } else {
-        return QModelIndex();
+        return {};
     }
 }
 
 QModelIndex SnippetsModel::parent(const QModelIndex &index) const
 {
     if (!index.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
-    SnippetItem *childItem = static_cast<SnippetItem *>(index.internalPointer());
+    auto childItem = static_cast<SnippetItem *>(index.internalPointer());
     SnippetItem *parentItem = childItem->parent();
 
     if (parentItem == mRootItem) {
-        return QModelIndex();
+        return {};
     }
 
     return createIndex(parentItem->row(), 0, parentItem);
@@ -423,7 +411,7 @@ bool SnippetsModel::insertRows(int row, int count, const QModelIndex &parent)
 
     beginInsertRows(parent, row, row + count - 1);
     for (int i = 0; i < count; ++i) {
-        SnippetItem *snippet = new SnippetItem(!parent.isValid(), parentItem);
+        auto snippet = new SnippetItem(!parent.isValid(), parentItem);
         parentItem->appendChild(snippet);
     }
     endInsertRows();
@@ -452,9 +440,7 @@ bool SnippetsModel::removeRows(int row, int count, const QModelIndex &parent)
 
 QStringList SnippetsModel::mimeTypes() const
 {
-    return
-        QStringList() << QStringLiteral("text/x-kmail-textsnippet")
-                      << QStringLiteral("text/plain");
+    return QStringList() << QStringLiteral("text/x-kmail-textsnippet") << QStringLiteral("text/plain");
 }
 
 QMimeData *SnippetsModel::mimeData(const QModelIndexList &indexes) const
@@ -465,25 +451,17 @@ QMimeData *SnippetsModel::mimeData(const QModelIndexList &indexes) const
 
     const QModelIndex index = indexes.first();
 
-    SnippetItem *item = static_cast<SnippetItem *>(index.internalPointer());
+    auto item = static_cast<SnippetItem *>(index.internalPointer());
     if (item->isGroup()) {
         return nullptr;
     }
 
-    QMimeData *mimeData = new QMimeData();
+    auto mimeData = new QMimeData();
 
     QByteArray encodedData;
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
-    stream << index.parent().internalId()
-           << item->name()
-           << item->text()
-           << item->keySequence()
-           << item->keyword()
-           << item->subject()
-           << item->to()
-           << item->cc()
-           << item->bcc()
-           << item->attachment();
+    stream << index.parent().internalId() << item->name() << item->text() << item->keySequence() << item->keyword() << item->subject() << item->to()
+           << item->cc() << item->bcc() << item->attachment();
 
     mimeData->setData(QStringLiteral("text/x-kmail-textsnippet"), encodedData);
     mimeData->setText(item->text());
@@ -493,7 +471,7 @@ QMimeData *SnippetsModel::mimeData(const QModelIndexList &indexes) const
 
 bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
-    Q_UNUSED(row);
+    Q_UNUSED(row)
 
     if (action == Qt::IgnoreAction) {
         return true;
@@ -508,7 +486,7 @@ bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
             return false;
         }
 
-        SnippetItem *item = static_cast<SnippetItem *>(parent.internalPointer());
+        auto item = static_cast<SnippetItem *>(parent.internalPointer());
 
         QByteArray encodedData = data->data(QStringLiteral("text/x-kmail-textsnippet"));
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
@@ -544,7 +522,17 @@ bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
             Q_EMIT dndDone();
             return true;
         } else {
-            if (KMessageBox::Yes == KMessageBox::questionYesNo(nullptr, i18n("Do you want to update snippet?"), i18n("Update snippet"))) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KMessageBox::ButtonCode::PrimaryAction
+                == KMessageBox::questionTwoActions(nullptr,
+                                                   i18n("Do you want to update snippet?"),
+                                                   i18n("Update snippet"),
+                                                   KGuiItem(i18n("Update")),
+                                                   KStandardGuiItem::cancel())) {
+#else
+            if (KMessageBox::Yes
+                == KMessageBox::questionYesNo(nullptr, i18n("Do you want to update snippet?"), i18n("Update snippet"), KGuiItem(i18n("Update")))) {
+#endif
                 item->setText(text);
                 item->setSubject(subject);
                 item->setTo(to);
@@ -563,12 +551,21 @@ bool SnippetsModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
             Q_EMIT addNewDndSnippset(encodedData);
             return false;
         }
-        SnippetItem *item = static_cast<SnippetItem *>(parent.internalPointer());
+        auto item = static_cast<SnippetItem *>(parent.internalPointer());
 
         if (item->isGroup()) {
             Q_EMIT addNewDndSnippset(encodedData);
         } else {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KMessageBox::ButtonCode::PrimaryAction
+                == KMessageBox::questionTwoActions(nullptr,
+                                                   i18n("Do you want to update snippet?"),
+                                                   i18n("Update snippet"),
+                                                   KGuiItem(i18n("Update")),
+                                                   KStandardGuiItem::cancel())) {
+#else
             if (KMessageBox::Yes == KMessageBox::questionYesNo(nullptr, i18n("Do you want to update snippet?"), i18n("Update snippet"))) {
+#endif
                 item->setText(encodedData);
             }
         }
@@ -592,16 +589,14 @@ QModelIndex SnippetsModel::createGroup(const QString &groupName)
 
 void SnippetsModel::load(const QString &filename)
 {
-    const KSharedConfig::Ptr config
-        = KSharedConfig::openConfig(filename.isEmpty() ? QStringLiteral("kmailsnippetrc") : filename, KConfig::NoGlobals);
+    const KSharedConfig::Ptr config = KSharedConfig::openConfig(filename.isEmpty() ? QStringLiteral("kmailsnippetrc") : filename, KConfig::NoGlobals);
 
     const KConfigGroup snippetPartGroup = config->group("SnippetPart");
 
     const int groupCount = snippetPartGroup.readEntry("snippetGroupCount", 0);
 
     for (int i = 0; i < groupCount; ++i) {
-        const KConfigGroup group
-            = config->group(QStringLiteral("SnippetGroup_%1").arg(i));
+        const KConfigGroup group = config->group(QStringLiteral("SnippetGroup_%1").arg(i));
 
         const QString groupName = group.readEntry("Name");
 
@@ -610,32 +605,23 @@ void SnippetsModel::load(const QString &filename)
 
         const int snippetCount = group.readEntry("snippetCount", 0);
         for (int j = 0; j < snippetCount; ++j) {
-            const QString snippetName
-                = group.readEntry(QStringLiteral("snippetName_%1").arg(j), QString());
+            const QString snippetName = group.readEntry(QStringLiteral("snippetName_%1").arg(j), QString());
 
-            const QString snippetText
-                = group.readEntry(QStringLiteral("snippetText_%1").arg(j), QString());
+            const QString snippetText = group.readEntry(QStringLiteral("snippetText_%1").arg(j), QString());
 
-            const QString snippetKeySequence
-                = group.readEntry(QStringLiteral("snippetKeySequence_%1").arg(j), QString());
+            const QString snippetKeySequence = group.readEntry(QStringLiteral("snippetKeySequence_%1").arg(j), QString());
 
-            const QString snippetKeyword
-                = group.readEntry(QStringLiteral("snippetKeyword_%1").arg(j), QString());
+            const QString snippetKeyword = group.readEntry(QStringLiteral("snippetKeyword_%1").arg(j), QString());
 
-            const QString snippetSubject
-                = group.readEntry(QStringLiteral("snippetSubject_%1").arg(j), QString());
+            const QString snippetSubject = group.readEntry(QStringLiteral("snippetSubject_%1").arg(j), QString());
 
-            const QString to
-                = group.readEntry(QStringLiteral("snippetTo_%1").arg(j), QString());
+            const QString to = group.readEntry(QStringLiteral("snippetTo_%1").arg(j), QString());
 
-            const QString cc
-                = group.readEntry(QStringLiteral("snippetCc_%1").arg(j), QString());
+            const QString cc = group.readEntry(QStringLiteral("snippetCc_%1").arg(j), QString());
 
-            const QString bcc
-                = group.readEntry(QStringLiteral("snippetBcc_%1").arg(j), QString());
+            const QString bcc = group.readEntry(QStringLiteral("snippetBcc_%1").arg(j), QString());
 
-            const QString attachment
-                = group.readEntry(QStringLiteral("snippetAttachment_%1").arg(j), QString());
+            const QString attachment = group.readEntry(QStringLiteral("snippetAttachment_%1").arg(j), QString());
             createSnippet(groupIndex, snippetName, snippetText, snippetKeySequence, snippetKeyword, snippetSubject, to, cc, bcc, attachment);
         }
     }
@@ -644,17 +630,23 @@ void SnippetsModel::load(const QString &filename)
     const int variablesCount = group.readEntry("variablesCount", 0);
 
     for (int i = 0; i < variablesCount; ++i) {
-        const QString variableKey
-            = group.readEntry(QStringLiteral("variableName_%1").arg(i), QString());
+        const QString variableKey = group.readEntry(QStringLiteral("variableName_%1").arg(i), QString());
 
-        const QString variableValue
-            = group.readEntry(QStringLiteral("variableValue_%1").arg(i), QString());
+        const QString variableValue = group.readEntry(QStringLiteral("variableValue_%1").arg(i), QString());
 
         mSavedVariables.insert(variableKey, variableValue);
     }
 }
 
-void SnippetsModel::createSnippet(const QModelIndex &groupIndex, const QString &snippetName, const QString &snippetText, const QString &snippetKeySequence, const QString &snippetKeyword, const QString &snippetSubject, const QString &to, const QString &cc, const QString &bcc,
+void SnippetsModel::createSnippet(const QModelIndex &groupIndex,
+                                  const QString &snippetName,
+                                  const QString &snippetText,
+                                  const QString &snippetKeySequence,
+                                  const QString &snippetKeyword,
+                                  const QString &snippetSubject,
+                                  const QString &to,
+                                  const QString &cc,
+                                  const QString &bcc,
                                   const QString &attachment)
 {
     insertRow(rowCount(groupIndex), groupIndex);
@@ -671,15 +663,7 @@ void SnippetsModel::createSnippet(const QModelIndex &groupIndex, const QString &
     setData(modelIndex, bcc, SnippetsModel::BccRole);
     setData(modelIndex, attachment, SnippetsModel::AttachmentRole);
 
-    Q_EMIT updateActionCollection(QString(),
-                                  snippetName,
-                                  QKeySequence::fromString(snippetKeySequence),
-                                  snippetText,
-                                  snippetSubject,
-                                  to,
-                                  cc,
-                                  bcc,
-                                  attachment);
+    Q_EMIT updateActionCollection(QString(), snippetName, QKeySequence::fromString(snippetKeySequence), snippetText, snippetSubject, to, cc, bcc, attachment);
 }
 
 void SnippetsModel::setSavedVariables(const QMap<QString, QString> &savedVariables)
@@ -735,7 +719,8 @@ void SnippetsModel::save(const QString &filename)
     KSharedConfig::Ptr config = KSharedConfig::openConfig(filename.isEmpty() ? QStringLiteral("kmailsnippetrc") : filename, KConfig::NoGlobals);
 
     // clear everything
-    for (const QString &group : config->groupList()) {
+    const QStringList lst = config->groupList();
+    for (const QString &group : lst) {
         config->deleteGroup(group);
     }
 
@@ -774,32 +759,25 @@ void SnippetsModel::save(const QString &filename)
                     group.writeEntry(QStringLiteral("snippetText_%1").arg(j), snippetText);
                 }
                 if (!snippetKeySequence.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetKeySequence_%1").arg(j),
-                                     snippetKeySequence);
+                    group.writeEntry(QStringLiteral("snippetKeySequence_%1").arg(j), snippetKeySequence);
                 }
                 if (!snippetKeyword.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetKeyword_%1").arg(j),
-                                     snippetKeyword);
+                    group.writeEntry(QStringLiteral("snippetKeyword_%1").arg(j), snippetKeyword);
                 }
                 if (!snippetSubject.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetSubject_%1").arg(j),
-                                     snippetSubject);
+                    group.writeEntry(QStringLiteral("snippetSubject_%1").arg(j), snippetSubject);
                 }
                 if (!snippetTo.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetTo_%1").arg(j),
-                                     snippetTo);
+                    group.writeEntry(QStringLiteral("snippetTo_%1").arg(j), snippetTo);
                 }
                 if (!snippetCc.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetCc_%1").arg(j),
-                                     snippetCc);
+                    group.writeEntry(QStringLiteral("snippetCc_%1").arg(j), snippetCc);
                 }
                 if (!snippetBcc.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetBcc_%1").arg(j),
-                                     snippetBcc);
+                    group.writeEntry(QStringLiteral("snippetBcc_%1").arg(j), snippetBcc);
                 }
                 if (!snippetAttachment.isEmpty()) {
-                    group.writeEntry(QStringLiteral("snippetAttachment_%1").arg(j),
-                                     snippetAttachment);
+                    group.writeEntry(QStringLiteral("snippetAttachment_%1").arg(j), snippetAttachment);
                 }
             }
         }
