@@ -2,7 +2,7 @@
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -35,8 +35,7 @@ private:
     void slotAccepted();
     const QString mVariableName;
     QMap<QString, QString> *mVariables = nullptr;
-    KPIMTextEdit::PlainTextEditorWidget *mVariableValueText = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *const mVariableValueText;
     QCheckBox *mSaveVariable = nullptr;
 };
 }
-
