@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -12,7 +12,6 @@
 
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityCombo>
-#include <KIdentityManagement/IdentityManager>
 
 #include <MailTransport/TransportComboBox>
 
@@ -38,12 +37,16 @@ public:
     {
     }
 
-    enum TypeAddress { ResendTo, ResendCc, ResendBcc };
+    enum TypeAddress {
+        ResendTo,
+        ResendCc,
+        ResendBcc,
+    };
 
     void slotUser1();
     void slotUser2();
     void slotAddressChanged(const QString &);
-    QString redirectLabelType(TypeAddress type) const;
+    Q_REQUIRED_RESULT QString redirectLabelType(TypeAddress type) const;
     RedirectDialog *const q = nullptr;
     RedirectWidget *mEditTo = nullptr;
     RedirectWidget *mEditCc = nullptr;
@@ -201,7 +204,7 @@ void RedirectDialog::accept()
 {
     const QString editTo = d->mEditTo->resend();
     if (editTo.isEmpty()) {
-        KMessageBox::sorry(this, i18n("You cannot redirect the message without an address."), i18n("Empty Redirection Address"));
+        KMessageBox::error(this, i18n("You cannot redirect the message without an address."), i18n("Empty Redirection Address"));
     } else {
         done(QDialog::Accepted);
     }
